代码修饰器 - layui

    //路由
    LAY.fn.router = function(hash){
      var hashs = (hash || location.hash).replace(/^#/, '').split('/') || [];
      var item, param = {
        dir: []
      };
      for(var i = 0; i < hashs.length; i++){
        item = hashs[i].split('=');
        /^\w+=/.test(hashs[i]) ? function(){
          if(item[0] !== 'dir'){
            param[item[0]] = item[1];
          }
        }() : param.dir.push(hashs[i]);
        item = null;
      }
      return param;
    };

    //路由
    LAY.fn.router = function(hash){
      var hashs = (hash || location.hash).replace(/^#/, '').split('/') || [];
      var item, param = {
        dir: []
      };
      for(var i = 0; i < hashs.length; i++){
        item = hashs[i].split('=');
        /^\w+=/.test(hashs[i]) ? function(){
          if(item[0] !== 'dir'){
            param[item[0]] = item[1];
          }
        }() : param.dir.push(hashs[i]);
        item = null;
      }
      return param;
    };

    var hashs = (hash || location.hash).replace(/^#/, '').split('/') || [];
    var item, param = {
      dir: []
    };

    //代码中的代码
    var hashs = (hash || location.hash).replace(/^#/, '').split('/') || [];
    var item, param = {
      dir: []
    };

    //路由
    LAY.fn.router = function(hash){
      var hashs = (hash || location.hash).replace(/^#/, '').split('/') || [];
      var item, param = {
        dir: []
      };
      for(var i = 0; i < hashs.length; i++){
        item = hashs[i].split('=');
        /^\w+=/.test(hashs[i]) ? function(){
          if(item[0] !== 'dir'){
            param[item[0]] = item[1];
          }
        }() : param.dir.push(hashs[i]);
        item = null;
      }
      return param;
    };

    //代码中的代码
    var hashs = (hash || location.hash).replace(/^#/, '').split('/') || [];
    var item, param = {
      dir: []
    };

    //代码中的代码
    var hashs = (hash || location.hash).replace(/^#/, '').split('/') || [];
    var item, param = {
      dir: []
    };

    //代码中的代码
    var hashs = (hash || location.hash).replace(/^#/, '').split('/') || [];
    var item, param = {
      dir: []
    };

        123